@@ -49,15 +49,31 @@ def given_a_MasterShapes_object_containing_2_shapes(context):
     context.master_shapes = prs.slide_masters[0].shapes
 
 
+@given('a notes slide')
+def given_a_notes_slide(context):
+    prs = Presentation(test_pptx('sld-notes'))
+    context.notes_slide = prs.slides[0].notes_slide
+
+
 @given('a slide')
 def given_a_slide(context):
-    presentation = Presentation(test_pptx('sld-access-shapes'))
+    presentation = Presentation(test_pptx('shp-shape-access'))
     context.slide = presentation.slides[0]
 
 
+@given('a slide having a notes slide')
+def given_a_slide_having_a_notes_slide(context):
+    context.slide = Presentation(test_pptx('sld-notes')).slides[0]
+
+
+@given('a slide having no notes slide')
+def given_a_slide_having_no_notes_slide(context):
+    context.slide = Presentation(test_pptx('sld-notes')).slides[1]
+
+
 @given('a slide having a title')
 def given_a_slide_having_a_title(context):
-    prs = Presentation(test_pptx('sld-access-shapes'))
+    prs = Presentation(test_pptx('shp-shape-access'))
     context.prs, context.slide = prs, prs.slides[0]
 
 
@@ -70,7 +86,7 @@ def given_a_slide_having_name_name(context, name):
 
 @given('a slide having slide id 256')
 def given_a_slide_having_slide_id_256(context):
-    presentation = Presentation(test_pptx('sld-access-shapes'))
+    presentation = Presentation(test_pptx('shp-shape-access'))
     context.slide = presentation.slides[0]
 
 
@@ -107,7 +123,7 @@ def given_a_SlideMasters_object_containing_2_masters(context):
 
 @given('a SlidePlaceholders object containing 2 placeholders')
 def given_a_SlidePlaceholders_object_containing_2_placeholders(context):
-    prs = Presentation(test_pptx('sld-access-shapes'))
+    prs = Presentation(test_pptx('shp-shape-access'))
     context.placeholders = prs.slides[0].placeholders
 
 
@@ -118,12 +134,6 @@ def given_a_Slides_object_containing_3_slides(context):
     context.slides = prs.slides
 
 
-@given('a SlideShapes object containing 6 shapes')
-def given_a_SlideShapes_object_containing_6_shapes(context):
-    presentation = Presentation(test_pptx('sld-access-shapes'))
-    context.shapes = presentation.slides[0].shapes
-
-
 # when ====================================================
 
 @when('I call slides.add_slide()')
@@ -179,6 +189,15 @@ def then_iterating_placeholders_produces_2_SlidePlaceholder_objects(context):
     assert idx == 1
 
 
+@then('iterating produces 3 NotesSlidePlaceholder objects')
+def then_iterating_produces_3_NotesSlidePlaceholder_objects(context):
+    idx = -1
+    for idx, placeholder in enumerate(context.notes_slide.placeholders):
+        typename = type(placeholder).__name__
+        assert typename == 'NotesSlidePlaceholder', 'got %s' % typename
+    assert idx == 2
+
+
 @then('iterating shapes produces 6 BaseShape objects')
 def then_iterating_shapes_produces_6_BaseShape_objects(context):
     shapes = context.shapes
@@ -260,6 +279,12 @@ def then_len_master_shapes_is_2(context):
     assert len(master_shapes) == 2
 
 
+@then('len(notes_slide.shapes) is {count}')
+def then_len_notes_slide_shapes_is_count(context, count):
+    shapes = context.notes_slide.shapes
+    assert len(shapes) == int(count)
+
+
 @then('len(placeholders) is 2')
 def then_len_placeholders_is_2(context):
     placeholders = context.placeholders
@@ -311,16 +336,37 @@ def then_master_shapes_1_is_a_Picture_object(context):
     assert type(master_shapes[1]).__name__ == 'Picture'
 
 
+@then('notes_slide.notes_placeholder is a NotesSlidePlaceholder object')
+def then_notes_slide_notes_placeholder_is_a_NotesSlidePlacehldr_obj(context):
+    notes_slide = context.notes_slide
+    cls_name = type(notes_slide.notes_placeholder).__name__
+    assert cls_name == 'NotesSlidePlaceholder', 'got %s' % cls_name
+
+
+@then('notes_slide.notes_text_frame is a TextFrame object')
+def then_notes_slide_notes_text_frame_is_a_TextFrame_object(context):
+    notes_slide = context.notes_slide
+    cls_name = type(notes_slide.notes_text_frame).__name__
+    assert cls_name == 'TextFrame', 'got %s' % cls_name
+
+
+@then('notes_slide.placeholders is a NotesSlidePlaceholders object')
+def then_notes_slide_placeholders_is_a_NotesSlidePlaceholders_object(context):
+    notes_slide = context.notes_slide
+    assert type(notes_slide.placeholders).__name__ == 'NotesSlidePlaceholders'
+
+
 @then('placeholders[10] is a SlidePlaceholder object')
 def then_placeholders_10_is_a_SlidePlaceholder_object(context):
     placeholders = context.placeholders
     assert type(placeholders[10]).__name__ == 'SlidePlaceholder'
 
 
-@then('shapes[4] is a GraphicFrame object')
-def then_shapes_4_is_a_GraphicFrame_object(context):
+@then('shapes[{idx}] is a {type_} object')
+def then_shapes_idx_is_a_type_object(context, idx, type_):
     shapes = context.shapes
-    assert type(shapes[4]).__name__ == 'GraphicFrame'
+    type_name = type(shapes[int(idx)]).__name__
+    assert type_name == type_, 'got %s' % type_name
 
 
 @then('shapes.title is the title placeholder')
@@ -331,6 +377,13 @@ def then_shapes_title_is_the_title_placeholder(context):
     assert title_placeholder.id == 4
 
 
+@then('slide.has_notes_slide is {value}')
+def then_slide_has_notes_slide_is_value(context, value):
+    expected_value = {'True': True, 'False': False}[value]
+    slide = context.slide
+    assert slide.has_notes_slide is expected_value
+
+
 @then('slide.name is {value}')
 def then_slide_name_is_value(context, value):
     expected_value = '' if value == 'the empty string' else value
@@ -338,6 +391,12 @@ def then_slide_name_is_value(context, value):
     assert slide.name == expected_value
 
 
+@then('slide.notes_slide is a NotesSlide object')
+def then_slide_notes_slide_is_a_NotesSlide_object(context):
+    notes_slide = context.notes_slide = context.slide.notes_slide
+    assert type(notes_slide).__name__ == 'NotesSlide'
+
+
 @then('slide.placeholders is a SlidePlaceholders object')
 def then_slide_placeholders_is_a_SlidePlaceholders_object(context):
     slide = context.slide
