@@ -19,8 +19,8 @@ from ..oxml.simpletypes import ST_Direction
 from .picture import Picture
 from .placeholder import (
     ChartPlaceholder, LayoutPlaceholder, MasterPlaceholder,
-    PicturePlaceholder, PlaceholderGraphicFrame, PlaceholderPicture,
-    SlidePlaceholder, TablePlaceholder
+    NotesSlidePlaceholder, PicturePlaceholder, PlaceholderGraphicFrame,
+    PlaceholderPicture, SlidePlaceholder, TablePlaceholder
 )
 from ..shared import ParentedElementProxy
 
@@ -75,6 +75,43 @@ class _BaseShapes(ParentedElementProxy):
         shape_elms = list(self._iter_member_elms())
         return len(shape_elms)
 
+    def clone_placeholder(self, placeholder):
+        """
+        Add a new placeholder shape based on *placeholder*.
+        """
+        sp = placeholder.element
+        ph_type, orient, sz, idx = (
+            sp.ph_type, sp.ph_orient, sp.ph_sz, sp.ph_idx
+        )
+        id_ = self._next_shape_id
+        name = self._next_ph_name(ph_type, id_, orient)
+        self._spTree.add_placeholder(id_, name, ph_type, orient, sz, idx)
+
+    def ph_basename(self, ph_type):
+        """
+        Return the base name for a placeholder of *ph_type* in this shape
+        collection. There is some variance between slide types, for example
+        a notes slide uses a different name for the body placeholder, so this
+        method can be overriden by subclasses.
+        """
+        return {
+            PP_PLACEHOLDER.BITMAP:       'ClipArt Placeholder',
+            PP_PLACEHOLDER.BODY:         'Text Placeholder',
+            PP_PLACEHOLDER.CENTER_TITLE: 'Title',
+            PP_PLACEHOLDER.CHART:        'Chart Placeholder',
+            PP_PLACEHOLDER.DATE:         'Date Placeholder',
+            PP_PLACEHOLDER.FOOTER:       'Footer Placeholder',
+            PP_PLACEHOLDER.HEADER:       'Header Placeholder',
+            PP_PLACEHOLDER.MEDIA_CLIP:   'Media Placeholder',
+            PP_PLACEHOLDER.OBJECT:       'Content Placeholder',
+            PP_PLACEHOLDER.ORG_CHART:    'SmartArt Placeholder',
+            PP_PLACEHOLDER.PICTURE:      'Picture Placeholder',
+            PP_PLACEHOLDER.SLIDE_NUMBER: 'Slide Number Placeholder',
+            PP_PLACEHOLDER.SUBTITLE:     'Subtitle',
+            PP_PLACEHOLDER.TABLE:        'Table Placeholder',
+            PP_PLACEHOLDER.TITLE:        'Title',
+        }[ph_type]
+
     @staticmethod
     def _is_member_elm(shape_elm):
         """
@@ -92,6 +129,33 @@ class _BaseShapes(ParentedElementProxy):
             if self._is_member_elm(shape_elm):
                 yield shape_elm
 
+    def _next_ph_name(self, ph_type, id, orient):
+        """
+        Next unique placeholder name for placeholder shape of type *ph_type*,
+        with id number *id* and orientation *orient*. Usually will be standard
+        placeholder root name suffixed with id-1, e.g.
+        _next_ph_name(ST_PlaceholderType.TBL, 4, 'horz') ==>
+        'Table Placeholder 3'. The number is incremented as necessary to make
+        the name unique within the collection. If *orient* is ``'vert'``, the
+        placeholder name is prefixed with ``'Vertical '``.
+        """
+        basename = self.ph_basename(ph_type)
+
+        # prefix rootname with 'Vertical ' if orient is 'vert'
+        if orient == ST_Direction.VERT:
+            basename = 'Vertical %s' % basename
+
+        # increment numpart as necessary to make name unique
+        numpart = id - 1
+        names = self._spTree.xpath('//p:cNvPr/@name')
+        while True:
+            name = '%s %d' % (basename, numpart)
+            if name not in names:
+                break
+            numpart += 1
+
+        return name
+
     @property
     def _next_shape_id(self):
         """
@@ -117,7 +181,9 @@ class _BaseShapes(ParentedElementProxy):
 class BasePlaceholders(_BaseShapes):
     """
     Base class for placeholder collections that differentiate behaviors for
-    a master, layout, and slide.
+    a master, layout, and slide. By default, placeholder shapes are
+    constructed using |BaseShapeFactory|. Subclasses should override
+    :method:`_shape_factory` to use custom placeholder classes.
     """
     @staticmethod
     def _is_member_elm(shape_elm):
@@ -138,7 +204,7 @@ class LayoutPlaceholders(BasePlaceholders):
         *default* if not found.
         """
         for placeholder in self:
-            if placeholder.idx == idx:
+            if placeholder.element.ph_idx == idx:
                 return placeholder
         return default
 
@@ -224,6 +290,59 @@ def _MasterShapeFactory(shape_elm, parent):
     return BaseShapeFactory(shape_elm, parent)
 
 
+class NotesSlidePlaceholders(MasterPlaceholders):
+    """
+    Sequence of placeholder shapes on a notes slide.
+    """
+    def _shape_factory(self, placeholder_elm):
+        """
+        Return an instance of the appropriate placeholder proxy class for
+        *placeholder_elm*.
+        """
+        return _NotesSlideShapeFactory(placeholder_elm, self)
+
+
+def _NotesSlideShapeFactory(shape_elm, parent):
+    """
+    Return an instance of the appropriate shape proxy class for *shape_elm*
+    on a notes slide.
+    """
+    tag_name = shape_elm.tag
+    if tag_name == qn('p:sp') and shape_elm.has_ph_elm:
+        return NotesSlidePlaceholder(shape_elm, parent)
+    return BaseShapeFactory(shape_elm, parent)
+
+
+class NotesSlideShapes(_BaseShapes):
+    """
+    Sequence of shapes appearing on a notes slide. The first shape in the
+    sequence is the backmost in z-order and the last shape is topmost.
+    Supports indexed access, len(), index(), and iteration.
+    """
+    def ph_basename(self, ph_type):
+        """
+        Return the base name for a placeholder of *ph_type* in this shape
+        collection. A notes slide uses a different name for the body
+        placeholder and has some unique placeholder types, so this
+        method overrides the default in the base class.
+        """
+        return {
+            PP_PLACEHOLDER.BODY:         'Notes Placeholder',
+            PP_PLACEHOLDER.DATE:         'Date Placeholder',
+            PP_PLACEHOLDER.FOOTER:       'Footer Placeholder',
+            PP_PLACEHOLDER.HEADER:       'Header Placeholder',
+            PP_PLACEHOLDER.SLIDE_IMAGE:  'Slide Image Placeholder',
+            PP_PLACEHOLDER.SLIDE_NUMBER: 'Slide Number Placeholder',
+        }[ph_type]
+
+    def _shape_factory(self, shape_elm):
+        """
+        Return an instance of the appropriate shape proxy class for
+        *shape_elm* appearing on a notes slide.
+        """
+        return _NotesSlideShapeFactory(shape_elm, self)
+
+
 def _SlidePlaceholderFactory(shape_elm, parent):
     """
     Return a placeholder shape of the appropriate type for *shape_elm*.
@@ -379,7 +498,7 @@ class SlideShapes(_BaseShapes):
         and footer) are not cloned.
         """
         for placeholder in slide_layout.iter_cloneable_placeholders():
-            self._clone_layout_placeholder(placeholder)
+            self.clone_placeholder(placeholder)
 
     def index(self, shape):
         """
@@ -503,65 +622,6 @@ class SlideShapes(_BaseShapes):
         sp = self._spTree.add_textbox(id_, name, x, y, cx, cy)
         return sp
 
-    def _clone_layout_placeholder(self, layout_placeholder):
-        """
-        Add a new placeholder shape based on the slide layout placeholder
-        *layout_ph*.
-        """
-        id_ = self._next_shape_id
-        ph_type = layout_placeholder.ph_type
-        orient = layout_placeholder.orient
-        name = self._next_ph_name(ph_type, id_, orient)
-        sz = layout_placeholder.sz
-        idx = layout_placeholder.idx
-
-        self._spTree.add_placeholder(id_, name, ph_type, orient, sz, idx)
-
-    def _next_ph_name(self, ph_type, id, orient):
-        """
-        Next unique placeholder name for placeholder shape of type *ph_type*,
-        with id number *id* and orientation *orient*. Usually will be standard
-        placeholder root name suffixed with id-1, e.g.
-        _next_ph_name(ST_PlaceholderType.TBL, 4, 'horz') ==>
-        'Table Placeholder 3'. The number is incremented as necessary to make
-        the name unique within the collection. If *orient* is ``'vert'``, the
-        placeholder name is prefixed with ``'Vertical '``.
-        """
-        basename = {
-            # BODY is named 'Notes Placeholder' in a notes master
-            PP_PLACEHOLDER.BODY:         'Text Placeholder',
-            PP_PLACEHOLDER.CHART:        'Chart Placeholder',
-            PP_PLACEHOLDER.BITMAP:       'ClipArt Placeholder',
-            PP_PLACEHOLDER.CENTER_TITLE: 'Title',
-            PP_PLACEHOLDER.ORG_CHART:    'SmartArt Placeholder',
-            PP_PLACEHOLDER.DATE:         'Date Placeholder',
-            PP_PLACEHOLDER.FOOTER:       'Footer Placeholder',
-            PP_PLACEHOLDER.HEADER:       'Header Placeholder',
-            PP_PLACEHOLDER.MEDIA_CLIP:   'Media Placeholder',
-            PP_PLACEHOLDER.OBJECT:       'Content Placeholder',
-            PP_PLACEHOLDER.PICTURE:      'Picture Placeholder',
-            # PP_PLACEHOLDER.SLIDE_IMAGE:  'Slide Image Placeholder',
-            PP_PLACEHOLDER.SLIDE_NUMBER: 'Slide Number Placeholder',
-            PP_PLACEHOLDER.SUBTITLE:     'Subtitle',
-            PP_PLACEHOLDER.TABLE:        'Table Placeholder',
-            PP_PLACEHOLDER.TITLE:        'Title',
-        }[ph_type]
-
-        # prefix rootname with 'Vertical ' if orient is 'vert'
-        if orient == ST_Direction.VERT:
-            basename = 'Vertical %s' % basename
-
-        # increment numpart as necessary to make name unique
-        numpart = id - 1
-        names = self._spTree.xpath('//p:cNvPr/@name')
-        while True:
-            name = '%s %d' % (basename, numpart)
-            if name not in names:
-                break
-            numpart += 1
-
-        return name
-
     def _shape_factory(self, shape_elm):
         """
         Return an instance of the appropriate shape proxy class for
